#include <scope/preview.h>

#include <unity/scopes/ColumnLayout.h>
#include <unity/scopes/PreviewWidget.h>
#include <unity/scopes/PreviewReply.h>
#include <unity/scopes/Result.h>
#include <unity/scopes/VariantBuilder.h>

#include <iostream>

namespace sc = unity::scopes;

using namespace std;
using namespace scope;

Preview::Preview(const sc::Result &result, const sc::ActionMetadata &metadata) :
    sc::PreviewQueryBase(result, metadata) {
}

void Preview::cancelled() {
}

void Preview::run(sc::PreviewReplyProxy const& reply) {
    // Support three different column layouts
    sc::ColumnLayout layout1col(1);

    // We define 3 different layouts, that will be used depending on the
    // device. The shell (view) will decide which layout fits best.
    // If, for instance, we are executing in a tablet probably the view will use
    // 2 or more columns.
    // Column layout definitions are optional.
    // However, we recommend that scopes define layouts for the best visual appearance.

    // Single column layout
    layout1col.add_column( { "image", "header", "summary","ratingId",  "infoId", "expId", "commendId", "commendId2", "actionId"});

    // Register the layouts we just created
    reply->register_layout( { layout1col});

    // Define the header section
    sc::PreviewWidget header("header", "header");
    // It has title and a subtitle properties
    header.add_attribute_mapping("title", "title");
    header.add_attribute_mapping("subtitle", "subtitle");

    // Define the image section
    sc::PreviewWidget image("image", "image");
    // It has a single source property, mapped to the result's art property
    image.add_attribute_mapping("source", "art");

    // Define the summary section
    sc::PreviewWidget description("summary", "text");
    // It has a text property, mapped to the result's description property
    description.add_attribute_mapping("text", "description");

    sc::PreviewWidget w_subTitle("subtitleId", "text");
    sc::PreviewWidget w_rating ("ratingId", "reviews");
    sc::PreviewWidget w_Info("infoId", "text");
    sc::PreviewWidget w_link("actionId", "actions");
    sc::PreviewWidget w_exp("expId", "expandable");
    sc::PreviewWidget w_commend("commendId", "rating-input" );
    sc::PreviewWidget w_commend2("commendId2", "comment-input" );
    sc::PreviewWidget w_description("description", "text");

    w_subTitle.add_attribute_value("text", sc::Variant("<i> subTitle </i>"));
    w_exp.add_attribute_value("title", sc::Variant("<b>Description: </b>"));
    w_description.add_attribute_value("text", sc::Variant("description \nldfkjalsdjf\n\n "
                                                                                            "jsldfkjalsdjf\nasdflkajsdlfkajdfs"));
    w_exp.add_attribute_value("collapsed-widgets", sc::Variant(2));
    w_exp.add_attribute_value("expanded", sc::Variant(false));

    w_exp.add_widget(w_commend);
    w_exp.add_widget(w_subTitle);
    w_exp.add_widget(w_Info);
    w_exp.add_widget(w_description);
    w_exp.add_widget(w_commend2);


    sc::VariantBuilder rat_builder;
    rat_builder.add_tuple({{"rating", sc::Variant(6)}});
    w_rating.add_attribute_value("reviews", rat_builder.end());

    sc::VariantBuilder builder;
    builder.add_tuple({
                            {"id", sc::Variant("open")},
                            {"label", sc::Variant("Google")},
                            {"uri", sc::Variant("http://www.google.com")}
                    });
    w_link.add_attribute_value("actions", builder.end());

    // Push each of the sections
    reply->push( { image, header, description ,w_rating,  w_exp,w_link});
}

